==> deb-installer_23.8.02.tar.xz: deb-installer-23.8.02/translations/deb-installer_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="118"/>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="90"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Následující balíky budou nainstalovány. Informaci o balících zobrazíte kliknutím na &apos;Zobrazit podrobnosti&apos;.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="98"/>
        <source>File: %1</source>
        <translation>Soubor: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="115"/>
        <source>Will install the following:</source>
        <translation>Tohle se nainstaluje:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="130"/>
        <source>Installing selected package please authenticate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="136"/>
        <source>Press any key to close</source>
        <translation>Zavřít stiskem libovolné klávesy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Program pro instalaci Debian balíčků (deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>soubory...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Název .deb souborů k instalaci</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[soubor...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Vybrat .deb soubory k instalaci</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb Soubory (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Nebyly poskutnuté žádné .deb soubory.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Soubor %1 nenalezen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Soubor %1 není .deb souborem.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Tento program musíte spustit jako normální uživatel</translation>
    </message>
</context>
</TS>

==> deb-installer_24.06.15.tar.xz: deb-installer-24.06.15/translations/deb-installer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="118"/>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="90"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Následující balíky budou nainstalovány. Informaci o balících zobrazíte kliknutím na &apos;Zobrazit podrobnosti&apos;.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="98"/>
        <source>File: %1</source>
        <translation>Soubor: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="115"/>
        <source>Will install the following:</source>
        <translation>Tohle se nainstaluje:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="130"/>
        <source>Installing selected package please authenticate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../installer.cpp" line="136"/>
        <source>Press any key to close</source>
        <translation>Zavřít stiskem libovolné klávesy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Program pro instalaci Debian balíčků (deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>soubory...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Název .deb souborů k instalaci</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[soubor...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Vybrat .deb soubory k instalaci</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb Soubory (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Nebyly poskutnuté žádné .deb soubory.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Soubor %1 nenalezen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Soubor %1 není .deb souborem.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Tento program musíte spustit jako normální uživatel</translation>
    </message>
</context>
</TS>
